@@ -167,6 +167,9 @@ elif board_id == ap_board.DRAGONBOARD_410C:
 elif board_id == ap_board.FTDI_FT232H:
     from adafruit_blinka.board.ftdi_ft232h import *
 
+elif board_id == ap_board.FTDI_FT2232H:
+    from adafruit_blinka.board.ftdi_ft2232h import *
+
 elif board_id == ap_board.BINHO_NOVA:
     from adafruit_blinka.board.binho_nova import *
 
@@ -224,6 +227,18 @@ elif board_id == ap_board.NANOPI_DUO2:
 elif board_id == ap_board.PICO_U2IF:
     from adafruit_blinka.board.pico_u2if import *
 
+elif board_id == ap_board.FEATHER_U2IF:
+    from adafruit_blinka.board.feather_u2if import *
+
+elif board_id == ap_board.QTPY_U2IF:
+    from adafruit_blinka.board.qtpy_u2if import *
+
+elif board_id == ap_board.ITSYBITSY_U2IF:
+    from adafruit_blinka.board.itsybitsy_u2if import *
+
+elif board_id == ap_board.QT2040_TRINKEY_U2IF:
+    from adafruit_blinka.board.qt2040_trinkey_u2if import *
+
 elif "sphinx" in sys.modules:
     pass
 
