@@ -56,7 +56,9 @@ elif detector.chip.RK3399:
 elif detector.chip.RK3328:
     from adafruit_blinka.microcontroller.rockchip.rk3328.pin import Pin
 elif detector.board.ftdi_ft232h:
-    from adafruit_blinka.microcontroller.ft232h.pin import Pin
+    from adafruit_blinka.microcontroller.ftdi_mpsse.ft232h.pin import Pin
+elif detector.board.ftdi_ft2232h:
+    from adafruit_blinka.microcontroller.ftdi_mpsse.ft2232h.pin import Pin
 elif detector.board.binho_nova:
     from adafruit_blinka.microcontroller.nova.pin import Pin
 elif detector.board.greatfet_one:
@@ -80,7 +82,14 @@ elif detector.chip.H6:
 elif detector.chip.H616:
     from adafruit_blinka.microcontroller.allwinner.h616.pin import Pin
 elif detector.board.pico_u2if:
-    from adafruit_blinka.microcontroller.pico_u2if.pin import Pin
+    from adafruit_blinka.microcontroller.rp2040_u2if.pin import Pin
+elif (
+    detector.board.feather_u2if
+    or detector.board.qtpy_u2if
+    or detector.board.itsybitsy_u2if
+    or detector.board.qt2040_trinkey_u2if
+):
+    from adafruit_blinka.microcontroller.rp2040_u2if.pin import Pin
 
 from adafruit_blinka import Enum, ContextManaged
 
