@@ -1,5 +1,6 @@
 """Microcontroller pins"""
 
+import sys
 import time
 
 from adafruit_platformdetect.constants import chips as ap_chip
@@ -103,11 +104,17 @@ elif chip_id == ap_chip.MIPS24KC:
     from adafruit_blinka.microcontroller.atheros.ar9331.pin import *
 elif chip_id == ap_chip.MIPS24KEC:
     from adafruit_blinka.microcontroller.mips24kec.pin import *
+elif chip_id == ap_chip.FT232H:
+    from adafruit_blinka.microcontroller.ftdi_mpsse.ft232h.pin import *
+elif chip_id == ap_chip.FT2232H:
+    from adafruit_blinka.microcontroller.ftdi_mpsse.ft2232h.pin import *
 elif chip_id == ap_chip.PENTIUM_N3710:
     from adafruit_blinka.microcontroller.pentium.n3710.pin import *
 elif chip_id == ap_chip.STM32MP157:
     from adafruit_blinka.microcontroller.stm32.stm32mp157.pin import *
 elif chip_id == ap_chip.MT8167:
     from adafruit_blinka.microcontroller.mt8167.pin import *
+elif "sphinx" in sys.modules:
+    pass
 else:
     raise NotImplementedError("Microcontroller not supported:", chip_id)
