@@ -51,7 +51,9 @@ elif chip_id == ap_chip.IMX6ULL:
 elif chip_id == ap_chip.HFU540:
     from adafruit_blinka.microcontroller.hfu540.pin import *
 elif chip_id == ap_chip.FT232H:
-    from adafruit_blinka.microcontroller.ft232h.pin import *
+    from adafruit_blinka.microcontroller.ftdi_mpsse.ft232h.pin import *
+elif chip_id == ap_chip.FT2232H:
+    from adafruit_blinka.microcontroller.ftdi_mpsse.ft2232h.pin import *
 elif chip_id == ap_chip.BINHO:
     from adafruit_blinka.microcontroller.nova.pin import *
 elif chip_id == ap_chip.LPC4330:
@@ -79,6 +81,6 @@ elif chip_id == ap_chip.STM32MP157:
 elif chip_id == ap_chip.MT8167:
     from adafruit_blinka.microcontroller.mt8167.pin import *
 elif chip_id == ap_chip.PICO_U2IF:
-    from adafruit_blinka.microcontroller.pico_u2if.pin import *
+    from adafruit_blinka.microcontroller.rp2040_u2if.pin import *
 else:
     raise NotImplementedError("Microcontroller not supported: ", chip_id)
